pub enum RequestValidationError {
UndeclaredAction {
action: Arc<EntityUID>,
},
UndeclaredPrincipalType {
principal_ty: EntityType,
},
UndeclaredResourceType {
resource_ty: EntityType,
},
InvalidPrincipalType {
principal_ty: EntityType,
action: Arc<EntityUID>,
},
InvalidResourceType {
resource_ty: EntityType,
action: Arc<EntityUID>,
},
InvalidContext {
context: Context,
action: Arc<EntityUID>,
},
TypeOfContext(GetSchemaTypeError),
}Variants
UndeclaredAction
Request action is not declared in the schema
UndeclaredPrincipalType
Request principal is of a type not declared in the schema
Fields
principal_ty: EntityTypePrincipal type which was not declared in the schema
UndeclaredResourceType
Request resource is of a type not declared in the schema
Fields
resource_ty: EntityTypeResource type which was not declared in the schema
InvalidPrincipalType
Request principal is of a type that is declared in the schema, but is not valid for the request action
Fields
principal_ty: EntityTypePrincipal type which is not valid
InvalidResourceType
Request resource is of a type that is declared in the schema, but is not valid for the request action
Fields
resource_ty: EntityTypeResource type which is not valid
InvalidContext
Context does not comply with the shape specified for the request action
Fields
TypeOfContext(GetSchemaTypeError)
Error computing the type of the Context; see the contained error type
for details about the kinds of errors that can occur